************
Installation
************

You can install ``dirtem`` with pip:

.. code-block:: bash
    
    pip install dirtem

There are two ways of using ``dirtem``. Either in the command-line or in a Python script.

